@@ -1,3 +1,4 @@
+import dataclasses
 import json
 import os
 import stat
@@ -42,7 +43,7 @@ from debputy.plugin.api.impl_types import (
     PluginProvidedKnownPackagingFile,
     DebputyPluginMetadata,
     KnownPackagingFileInfo,
-    InstallPatternDHCompatRule,
+    DHCompatibilityBasedRule,
     PackagerProvidedFileClassSpec,
     expand_known_packaging_config_features,
 )
@@ -80,6 +81,26 @@ PackagingFileInfo = TypedDict(
 )
 
 
+def _perl_json_bool(base: Optional[Any]) -> Optional[Any]:
+    if base is None:
+        return None
+
+    if isinstance(base, bool):
+        return base
+
+    # Account for different ways that Perl will or could return a JSON bool,
+    # when not using `JSON::PP::{true,false}`.
+    #
+    # https://salsa.debian.org/debian/debputy/-/issues/119#note_627057
+    if isinstance(base, int):
+        if base == 0:
+            return False
+        return True if base == 1 else base
+    if isinstance(base, str):
+        return False if base == "" else base
+    return base
+
+
 def scan_debian_dir(
     feature_set: PluginProvidedFeatureSet,
     source_package: SourcePackage,
@@ -127,12 +148,11 @@ def scan_debian_dir(
         for kpf in known_packaging_files.values()
         if kpf.detection_method == "dh.pkgfile"
     }
-
     if is_debputy_package:
         all_debputy_ppfs = list(
             flatten_ppfs(
                 detect_all_packager_provided_files(
-                    feature_set.packager_provided_files,
+                    feature_set,
                     debian_dir,
                     binary_packages,
                     allow_fuzzy_matches=True,
@@ -153,7 +173,7 @@ def scan_debian_dir(
             debian_dir,
             binary_packages,
             debputy_plugin_metadata,
-            dh_pkgfile_docs,
+            feature_set,
             dh_sequences,
             dh_compat_level,
             uses_dh_sequencer,
@@ -205,17 +225,7 @@ def scan_debian_dir(
 
     for virtual_path in _scan_debian_dir(debian_dir):
         key = virtual_path.path
-        if key in seen_paths:
-            continue
-        if virtual_path.is_symlink:
-            try:
-                st = os.stat(virtual_path.fs_path)
-            except FileNotFoundError:
-                continue
-            else:
-                if not stat.S_ISREG(st.st_mode):
-                    continue
-        elif not virtual_path.is_file:
+        if key in seen_paths or _skip_path(virtual_path):
             continue
 
         static_match = static_packaging_files.get(virtual_path.path)
@@ -232,6 +242,20 @@ def scan_debian_dir(
     return annotated, reference_data_set_names, dh_assistant_exit_code, dh_issues
 
 
+def _skip_path(virtual_path: VirtualPath) -> bool:
+    if virtual_path.is_symlink:
+        try:
+            st = os.stat(virtual_path.fs_path)
+        except FileNotFoundError:
+            return True
+        else:
+            if not stat.S_ISREG(st.st_mode):
+                return True
+    elif not virtual_path.is_file:
+        return True
+    return False
+
+
 def _fake_PPFClassSpec(
     debputy_plugin_metadata: DebputyPluginMetadata,
     stem: str,
@@ -273,7 +297,7 @@ def _fake_PPFClassSpec(
 def _relevant_dh_compat_rules(
     compat_level: Optional[int],
     info: KnownPackagingFileInfo,
-) -> Iterable[InstallPatternDHCompatRule]:
+) -> Iterable[DHCompatibilityBasedRule]:
     if compat_level is None:
         return
     dh_compat_rules = info.get("dh_compat_rules")
@@ -301,7 +325,7 @@ def resolve_debhelper_config_files(
     debian_dir: VirtualPath,
     binary_packages: Mapping[str, BinaryPackage],
     debputy_plugin_metadata: DebputyPluginMetadata,
-    dh_ppf_docs: Dict[str, PluginProvidedKnownPackagingFile],
+    plugin_feature_set: PluginProvidedFeatureSet,
     dh_rules_addons: AbstractSet[str],
     dh_compat_level: int,
     saw_dh: bool,
@@ -310,6 +334,13 @@ def resolve_debhelper_config_files(
     debputy_integration_mode: Optional[DebputyIntegrationMode] = None,
     cwd: Optional[str] = None,
 ) -> Tuple[List[PackagerProvidedFile], Optional[object], int]:
+
+    dh_ppf_docs = {
+        kpf.detection_value: kpf
+        for kpf in plugin_feature_set.known_packaging_files.values()
+        if kpf.detection_method == "dh.pkgfile"
+    }
+
     dh_ppfs = {}
     commands, exit_code = _relevant_dh_commands(dh_rules_addons, cwd=cwd)
 
@@ -402,7 +433,7 @@ def resolve_debhelper_config_files(
                         seen_docs.add(manpage)
                 else:
                     continue
-                is_active = command.get("is-active", True)
+                is_active = _perl_json_bool(command.get("is-active", True))
                 if is_active is None and command_name in dh_commands.active_commands:
                     is_active = True
                 if not isinstance(is_active, bool):
@@ -459,10 +490,11 @@ def resolve_debhelper_config_files(
             packageless_is_fallback_for_all_packages=packageless_is_fallback_for_all_packages,
             has_active_command=has_active_command,
         )
+    dh_ppf_feature_set = _fake_plugin_feature_set(plugin_feature_set, dh_ppfs)
     all_dh_ppfs = list(
         flatten_ppfs(
             detect_all_packager_provided_files(
-                dh_ppfs,
+                dh_ppf_feature_set,
                 debian_dir,
                 binary_packages,
                 allow_fuzzy_matches=True,
@@ -474,6 +506,13 @@ def resolve_debhelper_config_files(
     return all_dh_ppfs, issues, exit_code
 
 
+def _fake_plugin_feature_set(
+    plugin_feature_set: PluginProvidedFeatureSet,
+    fake_defs: Mapping[str, PackagerProvidedFileClassSpec],
+) -> PluginProvidedFeatureSet:
+    return dataclasses.replace(plugin_feature_set, packager_provided_files=fake_defs)
+
+
 def _merge_list(
     existing_table: Dict[str, Any],
     key: str,
