@@ -350,6 +350,13 @@ def lint_cmd(context: CommandContext) -> None:
             default=None,
             help="The formatting style to use (overrides packaging style).",
         ),
+        add_arg(
+            "--write-style",
+            dest="write_style",
+            action="store_true",
+            default=False,
+            help="Add the chosen style (from --style) into the reformatted debian/control.",
+        ),
         add_arg(
             "--auto-fix",
             dest="auto_fix",
