@@ -122,6 +122,7 @@ class DbgsymInfo:
     dbgsym_fs_root: FSPath
     _dbgsym_root_fs: Optional[str]
     dbgsym_ids: List[str]
+    run_dwz: bool
 
     @property
     def dbgsym_root_dir(self) -> str:
@@ -1515,6 +1516,8 @@ class HighLevelManifest:
                     dbgsym_root_fs,
                     os.path.join(dh_dbgsym_root_fs, "DEBIAN"),
                     dbgsym_build_ids,
+                    # TODO: Provide manifest feature to support this.
+                    False,
                 )
             else:
                 dbgsym_info = DbgsymInfo(
@@ -1522,6 +1525,7 @@ class HighLevelManifest:
                     FSRootDir(),
                     None,
                     [],
+                    False,
                 )
 
             package_data_dict[package] = BinaryPackageData(
