@@ -4,7 +4,17 @@ import stat
 import subprocess
 import sys
 import textwrap
-from typing import Optional, List, Union, NoReturn, Mapping, Sequence, TYPE_CHECKING
+from contextlib import suppress
+from typing import (
+    Optional,
+    List,
+    Union,
+    NoReturn,
+    Mapping,
+    Sequence,
+    TYPE_CHECKING,
+    Callable,
+)
 
 from debputy.commands.debputy_cmd.context import CommandContext
 from debputy.commands.debputy_cmd.output import _output_styling, IOBasedOutputStyling
@@ -40,6 +50,10 @@ from debputy.lsp.languages.lsp_debian_tests_control import (
 from debputy.lsp.languages.lsp_debian_upstream_metadata import (
     _lint_debian_upstream_metadata,
 )
+from debputy.lsp.languages.lsp_debian_watch import (
+    _lint_debian_watch,
+    _reformat_debian_watch,
+)
 from debputy.lsp.maint_prefs import (
     MaintainerPreferenceTable,
     EffectiveFormattingPreference,
@@ -53,7 +67,10 @@ from debputy.lsp.text_edit import (
     apply_text_edits,
     OverLappingTextEditException,
 )
-from debputy.lsp.vendoring._deb822_repro import Deb822FileElement
+from debputy.lsp.vendoring._deb822_repro import (
+    Deb822FileElement,
+    Deb822ParagraphElement,
+)
 from debputy.packages import SourcePackage, BinaryPackage
 from debputy.plugin.api import VirtualPath
 from debputy.plugin.api.feature_set import PluginProvidedFeatureSet
@@ -76,6 +93,7 @@ LINTER_FORMATS = {
     "debian/rules": _lint_debian_rules,
     "debian/patches/series": _lint_debian_patches_series,
     "debian/tests/control": _lint_debian_tests_control,
+    "debian/watch": _lint_debian_watch,
 }
 
 
@@ -83,6 +101,7 @@ REFORMAT_FORMATS = {
     "debian/control": _reformat_debian_control,
     "debian/copyright": _reformat_debian_copyright,
     "debian/tests/control": _reformat_debian_tests_control,
+    "debian/watch": _reformat_debian_watch,
 }
 
 
@@ -248,6 +267,8 @@ def perform_reformat(
     parsed_args = context.parsed_args
     fo = _output_styling(context.parsed_args, sys.stdout)
     lint_context = gather_lint_info(context)
+    write_style = parsed_args.write_style
+
     if named_style is not None:
         style = lint_context.maint_preference_table.named_styles.get(named_style)
         if style is None:
@@ -263,6 +284,9 @@ def perform_reformat(
             _info("This may be a non-issue (if the configuration is out of date).")
         lint_context.effective_preference = style
 
+    elif write_style:
+        _error("The `--write-style` option requires a named style passed via `--style`")
+
     if lint_context.effective_preference is None:
         if lint_context.unsupported_preference_reason is not None:
             _warn(
@@ -330,18 +354,49 @@ def perform_reformat(
 
     changes = False
     auto_fix = context.parsed_args.auto_fix
+    modifiers = {}
+    if write_style:
+
+        def _commit_style(raw: str) -> str:
+            deb822_file, _, _ = context.dctrl_parser.parse_source_debian_control(
+                raw.splitlines(keepends=True), ignore_errors=True
+            )
+
+            for p in deb822_file.iter_parts():
+                if p.is_error:
+                    _warn(
+                        "Cannot commit the style due to syntax errors in debian/control. Fix these first."
+                    )
+                    return raw
+                if isinstance(p, Deb822ParagraphElement):
+                    inserted = "X-Style" not in p
+                    p["X-Style"] = named_style
+                    # If we inserted the field, then we have opinions on its placement. But if it was already
+                    # there, then we do not re-order it.
+                    if inserted:
+                        with suppress(KeyError):
+                            p.order_before("X-Style", "Description")
+                    break
+
+            return deb822_file.dump()
+
+        modifiers["debian/control"] = _commit_style
+
     for name_stem in REFORMAT_FORMATS:
         formatter = REFORMAT_FORMATS.get(name_stem)
         filename = f"./{name_stem}"
         if formatter is None or not os.path.isfile(filename):
             continue
 
+        modifier = modifiers.get(name_stem)
+
         reformatted = perform_reformat_of_file(
             fo,
             lint_context,
             filename,
             formatter,
             auto_fix,
+            custom_modifier=modifier,
         )
         if reformatted:
             changes = True
@@ -356,6 +411,8 @@ def perform_reformat_of_file(
     filename: str,
     formatter: FormatterImpl,
     auto_fix: bool,
+    *,
+    custom_modifier: Optional[Callable[[str], str]] = None,
 ) -> bool:
     with open(filename, "rt", encoding="utf-8") as fd:
         text = fd.read()
@@ -368,15 +425,22 @@ def perform_reformat_of_file(
         None,
     )
     edits = formatter(lint_state)
-    if not edits:
+
+    if not edits and not custom_modifier:
         return False
 
-    try:
-        replacement = apply_text_edits(text, lines, edits)
-    except OverLappingTextEditException:
-        _error(
-            f"The reformater for {filename} produced overlapping edits (which is broken and will not work)"
-        )
+    if edits:
+        try:
+            replacement = apply_text_edits(text, lines, edits)
+        except OverLappingTextEditException:
+            _error(
+                f"The reformater for {filename} produced overlapping edits (which is broken and will not work)"
+            )
+    else:
+        replacement = text
+
+    if custom_modifier:
+        replacement = custom_modifier(replacement)
 
     output_filename = f"{filename}.tmp"
     with open(output_filename, "wt", encoding="utf-8") as fd:
