@@ -198,7 +198,7 @@ class LintState:
     def plugin_feature_set(self) -> PluginProvidedFeatureSet:
         """The plugin features known to the running instance of `debputy`
 
-        This is mostly only relevant when working with `debputy.manifest
+        This is mostly only relevant when working with `debputy.manifest`
         """
         raise NotImplementedError
 
@@ -356,7 +356,7 @@ class LintState:
         """Provide a related context for the diagnostic
 
         The related diagnostic information is typically highlighted with the diagnostic. As an example,
-        `debputy lint`'s terminal output will display the message and display the selected range after the
+        `debputy lint`'s terminal output will display the message and display the selected range after
         the diagnostic itself.
 
         :param text_range: The text range to highlight.
