@@ -1,4 +1,3 @@
-import asyncio
 import dataclasses
 import importlib.resources
 import os.path
@@ -187,14 +186,14 @@ def _as_substvars_metadata(
     return r
 
 
-def substvars_metadata_basename() -> str:
-    return "debian_control_substvars_data.yaml"
+def dctrl_variables_metadata_basename() -> str:
+    return "debian_control_variables_data.yaml"
 
 
 @lru_cache
-def substvars_metadata() -> Mapping[str, SubstvarMetadata]:
+def dctrl_substvars_metadata() -> Mapping[str, SubstvarMetadata]:
     p = importlib.resources.files(deb822_ref_data_dir.__name__).joinpath(
-        substvars_metadata_basename()
+        dctrl_variables_metadata_basename()
     )
 
     with p.open("r", encoding="utf-8") as fd:
@@ -203,7 +202,7 @@ def substvars_metadata() -> Mapping[str, SubstvarMetadata]:
     attr_path = AttributePath.root_path(p)
     ref = DCTRL_SUBSTVARS_REFERENCE_DATA_PARSER.parse_input(raw, attr_path)
     return _as_substvars_metadata(
-        [SubstvarMetadata.from_ref_data(x) for x in ref["substvars"]]
+        [SubstvarMetadata.from_ref_data(x) for x in ref["variables"]]
     )
 
 
@@ -549,7 +548,7 @@ def _custom_hover(
         pass
 
     if substvar == "${}" or SUBSTVAR_RE.fullmatch(substvar):
-        substvar_md = substvars_metadata().get(substvar)
+        substvar_md = dctrl_substvars_metadata().get(substvar)
 
         computed_doc = ""
         for_field = relationship_substvar_for_field(substvar)
@@ -569,7 +568,7 @@ def _custom_hover(
             md_fields = ""
         else:
             doc = ls.translation(LSP_DATA_DOMAIN).pgettext(
-                f"Substvars:{substvar_md.name}",
+                f"Variable:{substvar_md.name}",
                 substvar_md.description,
             )
             md_fields = "\n" + substvar_md.render_metadata_fields()
@@ -800,6 +799,9 @@ def _binary_package_checks(
 async def _lint_debian_control(lint_state: LintState) -> None:
     deb822_file = lint_state.parsed_deb822_file_content
 
+    if not _DCTRL_FILE_METADATA.file_metadata_applies_to_file(deb822_file):
+        return
+
     first_error = await scan_for_syntax_errors_and_token_level_diagnostics(
         deb822_file,
         lint_state,
