@@ -3,26 +3,14 @@ from typing import List, TYPE_CHECKING, Sequence
 
 import pytest
 
-from debputy.filesystem_scan import build_virtual_fs
-from debputy.lsp.config.config_options import DCO_SPELLCHECK_COMMENTS
 from debputy.lsp.languages.lsp_debian_control import _reformat_debian_control
-from debputy.lsp.lsp_debian_control_reference_data import CURRENT_STANDARDS_VERSION
 from debputy.lsp.maint_prefs import MaintainerPreferenceTable
 from debputy.lsp.text_edit import apply_text_edits
-from debputy.lsp.vendoring._deb822_repro import parse_deb822_file
-from debputy.lsprotocol.types import DiagnosticSeverity
 from debputy.packages import DctrlParser
-from debputy.plugin.api import virtual_path_def
 from debputy.plugin.api.feature_set import PluginProvidedFeatureSet
 from lint_tests.lint_tutil import (
-    group_diagnostics_by_severity,
-    requires_levenshtein,
-    LintWrapper,
-    diag_range_to_text,
     ReformatWrapper,
 )
-from tutil import build_time_only, with_plugins_loaded
-
 
 if TYPE_CHECKING:
     import lsprotocol.types as types
